#ifndef DIALOGS_H
#define DIALOGS_H

#include <QtGui>
#include "stickynoteswidget.hpp"

class Dialogs : public QObject
{
    Q_OBJECT

private:
    explicit Dialogs(QObject *parent = NULL);

public:
    static Dialogs *instance();

public slots:
    void showQuickOptionsDialog();
    void showBackgroundColorSelection();
    void showForegroundColorSelection();
    void showFontSelection();
    void showAboutDialog();

};

#endif // DIALOGS_H
